tsseg.algorithms.window package
===============================

Sliding-window discrepancy scoring between adjacent windows, peaks indicate change
points.

| **Type:** change point detection
| **Supervision:** semi-supervised or unsupervised
| **Scope:** multiple cost models

**Implementation:** Vendored from ruptures v1.1.8. BSD 2-Clause.

**Reference:** Basseville & Nikiforov (1993).

Module contents
---------------

.. automodule:: tsseg.algorithms.window
   :members:
   :show-inheritance:
   :undoc-members:
